@@ -23,6 +23,7 @@ from tencentcloud.ecdn.v20191012 import models
 class EcdnClient(AbstractClient):
     _apiVersion = '2019-10-12'
     _endpoint = 'ecdn.tencentcloudapi.com'
+    _service = 'ecdn'
 
 
     def AddEcdnDomain(self, request):
@@ -199,7 +200,6 @@ class EcdnClient(AbstractClient):
         + 流量（单位为 byte）
         + 带宽（单位为 bps）
         + 请求数（单位为 次）
-        + 响应时间（单位为ms）
         + 状态码 2xx 汇总及各 2 开头状态码明细（单位为 个）
         + 状态码 3xx 汇总及各 3 开头状态码明细（单位为 个）
         + 状态码 4xx 汇总及各 4 开头状态码明细（单位为 个）
@@ -231,7 +231,7 @@ class EcdnClient(AbstractClient):
 
 
     def DescribeIpStatus(self, request):
-        """DescribeIpStatus 用于查询域名所在加速平台的所有节点明细。
+        """DescribeIpStatus 用于查询域名所在加速平台的所有节点信息, 如果您的源站有白名单设置,可以通过本接口获取ECDN服务的节点IP进行加白, 本接口为内测接口,请联系腾讯云工程师开白。
 
         :param request: Request instance for DescribeIpStatus.
         :type request: :class:`tencentcloud.ecdn.v20191012.models.DescribeIpStatusRequest`
