@@ -355,7 +355,7 @@ class FuseFaceResponse(AbstractModel):
 
 
 class FuseFaceReviewDetail(AbstractModel):
-    """人脸融合鉴黄鉴政人脸信息
+    """人脸融合不适宜内容识别人脸信息
 
     """
 
@@ -390,7 +390,7 @@ BLOCK：违规
 
 
 class FuseFaceReviewResult(AbstractModel):
-    """人脸融合鉴黄鉴政返回参数item
+    """人脸融合不适宜内容识别返回参数item
 
     """
 
