@@ -50,6 +50,9 @@ class AllDeviceInfo(AbstractModel):
         :param IsRecord: 是否存在录像,，0:不存在；1：存在
 注意：此字段可能返回 null，表示取不到有效值。
         :type IsRecord: int
+        :param Recordable: 该设备是否可录制
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Recordable: int
         """
         self.DeviceId = None
         self.DeviceType = None
@@ -60,6 +63,7 @@ class AllDeviceInfo(AbstractModel):
         self.GroupPath = None
         self.DeviceCode = None
         self.IsRecord = None
+        self.Recordable = None
 
 
     def _deserialize(self, params):
@@ -72,6 +76,7 @@ class AllDeviceInfo(AbstractModel):
         self.GroupPath = params.get("GroupPath")
         self.DeviceCode = params.get("DeviceCode")
         self.IsRecord = params.get("IsRecord")
+        self.Recordable = params.get("Recordable")
 
 
 class BindGroupDevicesRequest(AbstractModel):
@@ -255,17 +260,22 @@ class CreateDeviceResponse(AbstractModel):
         :param DeviceId: 设备唯一标识
 注意：此字段可能返回 null，表示取不到有效值。
         :type DeviceId: str
+        :param VirtualGroupId: 设备虚拟组信息，仅在创建NVR/VMS时返回该值
+注意：此字段可能返回 null，表示取不到有效值。
+        :type VirtualGroupId: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self.DeviceCode = None
         self.DeviceId = None
+        self.VirtualGroupId = None
         self.RequestId = None
 
 
     def _deserialize(self, params):
         self.DeviceCode = params.get("DeviceCode")
         self.DeviceId = params.get("DeviceId")
+        self.VirtualGroupId = params.get("VirtualGroupId")
         self.RequestId = params.get("RequestId")
 
 
@@ -843,11 +853,14 @@ class DescribeGroupDevicesRequest(AbstractModel):
         :type Limit: int
         :param NickName: 设备名称，根据设备名称模糊匹配时必填
         :type NickName: str
+        :param Recordable: 过滤不可录制设备
+        :type Recordable: int
         """
         self.GroupId = None
         self.Offset = None
         self.Limit = None
         self.NickName = None
+        self.Recordable = None
 
 
     def _deserialize(self, params):
@@ -855,6 +868,7 @@ class DescribeGroupDevicesRequest(AbstractModel):
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
         self.NickName = params.get("NickName")
+        self.Recordable = params.get("Recordable")
 
 
 class DescribeGroupDevicesResponse(AbstractModel):
@@ -933,6 +947,95 @@ class DescribeGroupsResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeRecordStreamData(AbstractModel):
+    """DescribeRecordStreamData 复杂类型
+
+    """
+
+    def __init__(self):
+        """
+        :param RtspAddr: Rtsp地址
+        :type RtspAddr: str
+        :param RtmpAddr: Rtmp地址
+        :type RtmpAddr: str
+        :param HlsAddr: Hls地址
+        :type HlsAddr: str
+        :param FlvAddr: Flv地址
+        :type FlvAddr: str
+        :param StreamId: 流Id
+        :type StreamId: str
+        """
+        self.RtspAddr = None
+        self.RtmpAddr = None
+        self.HlsAddr = None
+        self.FlvAddr = None
+        self.StreamId = None
+
+
+    def _deserialize(self, params):
+        self.RtspAddr = params.get("RtspAddr")
+        self.RtmpAddr = params.get("RtmpAddr")
+        self.HlsAddr = params.get("HlsAddr")
+        self.FlvAddr = params.get("FlvAddr")
+        self.StreamId = params.get("StreamId")
+
+
+class DescribeRecordStreamRequest(AbstractModel):
+    """DescribeRecordStream请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param DeviceId: 设备Id
+        :type DeviceId: str
+        :param ExpireTime: 流失效时间
+        :type ExpireTime: int
+        :param RecordId: 录像文件Id
+        :type RecordId: str
+        :param StartTime: 录像流开始时间，当录像文件Id为空时有效
+        :type StartTime: int
+        :param EndTime: 录像流结束时间，当录像文件Id为空时有效
+        :type EndTime: int
+        """
+        self.DeviceId = None
+        self.ExpireTime = None
+        self.RecordId = None
+        self.StartTime = None
+        self.EndTime = None
+
+
+    def _deserialize(self, params):
+        self.DeviceId = params.get("DeviceId")
+        self.ExpireTime = params.get("ExpireTime")
+        self.RecordId = params.get("RecordId")
+        self.StartTime = params.get("StartTime")
+        self.EndTime = params.get("EndTime")
+
+
+class DescribeRecordStreamResponse(AbstractModel):
+    """DescribeRecordStream返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param Data: 结果
+        :type Data: :class:`tencentcloud.iotvideoindustry.v20201201.models.DescribeRecordStreamData`
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.Data = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("Data") is not None:
+            self.Data = DescribeRecordStreamData()
+            self.Data._deserialize(params.get("Data"))
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeSIPServerRequest(AbstractModel):
     """DescribeSIPServer请求参数结构体
 
@@ -1137,6 +1240,62 @@ class DescribeSubGroupsResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeVideoListRequest(AbstractModel):
+    """DescribeVideoList请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param StartTime: 开始时间戳，秒级
+        :type StartTime: int
+        :param EndTime: 结束时间戳，秒级
+        :type EndTime: int
+        :param Offset: 偏移
+        :type Offset: int
+        :param Limit: 限制
+        :type Limit: int
+        """
+        self.StartTime = None
+        self.EndTime = None
+        self.Offset = None
+        self.Limit = None
+
+
+    def _deserialize(self, params):
+        self.StartTime = params.get("StartTime")
+        self.EndTime = params.get("EndTime")
+        self.Offset = params.get("Offset")
+        self.Limit = params.get("Limit")
+
+
+class DescribeVideoListResponse(AbstractModel):
+    """DescribeVideoList返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param TotalCount: 总数
+        :type TotalCount: int
+        :param VideoList: 录像详情列表
+        :type VideoList: :class:`tencentcloud.iotvideoindustry.v20201201.models.RecordTaskItem`
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.TotalCount = None
+        self.VideoList = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.TotalCount = params.get("TotalCount")
+        if params.get("VideoList") is not None:
+            self.VideoList = RecordTaskItem()
+            self.VideoList._deserialize(params.get("VideoList"))
+        self.RequestId = params.get("RequestId")
+
+
 class DevGroupInfo(AbstractModel):
     """设备所在分组信息
 
@@ -1530,6 +1689,9 @@ class GroupDeviceItem(AbstractModel):
         :param IsRecord: 是否存在录像
 注意：此字段可能返回 null，表示取不到有效值。
         :type IsRecord: int
+        :param Recordable: 该设备是否可录制
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Recordable: int
         """
         self.DeviceId = None
         self.NickName = None
@@ -1539,6 +1701,7 @@ class GroupDeviceItem(AbstractModel):
         self.RTSPUrl = None
         self.DeviceCode = None
         self.IsRecord = None
+        self.Recordable = None
 
 
     def _deserialize(self, params):
@@ -1550,6 +1713,7 @@ class GroupDeviceItem(AbstractModel):
         self.RTSPUrl = params.get("RTSPUrl")
         self.DeviceCode = params.get("DeviceCode")
         self.IsRecord = params.get("IsRecord")
+        self.Recordable = params.get("Recordable")
 
 
 class GroupInfo(AbstractModel):
@@ -1575,6 +1739,12 @@ class GroupInfo(AbstractModel):
         :type ExtraInformation: str
         :param CreateTime: 创建时间
         :type CreateTime: int
+        :param GroupStatus: 分组状态
+注意：此字段可能返回 null，表示取不到有效值。
+        :type GroupStatus: int
+        :param Error: 设备不存在时产生的错误
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Error: str
         """
         self.GroupId = None
         self.GroupName = None
@@ -1584,6 +1754,8 @@ class GroupInfo(AbstractModel):
         self.GroupDescribe = None
         self.ExtraInformation = None
         self.CreateTime = None
+        self.GroupStatus = None
+        self.Error = None
 
 
     def _deserialize(self, params):
@@ -1595,6 +1767,8 @@ class GroupInfo(AbstractModel):
         self.GroupDescribe = params.get("GroupDescribe")
         self.ExtraInformation = params.get("ExtraInformation")
         self.CreateTime = params.get("CreateTime")
+        self.GroupStatus = params.get("GroupStatus")
+        self.Error = params.get("Error")
 
 
 class GroupItem(AbstractModel):
@@ -1634,6 +1808,9 @@ class GroupItem(AbstractModel):
         :param CreateTime: 创建时间
 注意：此字段可能返回 null，表示取不到有效值。
         :type CreateTime: int
+        :param GroupStatus: 分组状态
+注意：此字段可能返回 null，表示取不到有效值。
+        :type GroupStatus: int
         """
         self.GroupName = None
         self.ParentId = None
@@ -1645,6 +1822,7 @@ class GroupItem(AbstractModel):
         self.ExtraInformation = None
         self.GroupType = None
         self.CreateTime = None
+        self.GroupStatus = None
 
 
     def _deserialize(self, params):
@@ -1658,6 +1836,7 @@ class GroupItem(AbstractModel):
         self.ExtraInformation = params.get("ExtraInformation")
         self.GroupType = params.get("GroupType")
         self.CreateTime = params.get("CreateTime")
+        self.GroupStatus = params.get("GroupStatus")
 
 
 class ModifyDeviceDataRequest(AbstractModel):
